Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(460)

Unified Diff: ios/chrome/browser/reading_list/reading_list_distiller_page.h

Issue 2754803003: Reading List iOS: Handle multiple pages. (Closed)
Patch Set: rebase Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ios/chrome/browser/reading_list/reading_list_distiller_page.h
diff --git a/ios/chrome/browser/reading_list/reading_list_distiller_page.h b/ios/chrome/browser/reading_list/reading_list_distiller_page.h
index 9b139f24bd708cf292d8cb8809b1f2989b9eec82..2a80e449042c9ba329ecacd9ea0a5f2ac0881930 100644
--- a/ios/chrome/browser/reading_list/reading_list_distiller_page.h
+++ b/ios/chrome/browser/reading_list/reading_list_distiller_page.h
@@ -45,10 +45,11 @@ class ReadingListDistillerPage : public dom_distiller::DistillerPageIOS {
public:
typedef base::Callback<void(const GURL&, const GURL&)> RedirectionCallback;
// Creates a ReadingListDistillerPage. WebStates to download the pages will
// be provided by web_state_dispatcher.
// |browser_state|, |web_state_dispatcher| and |delegate| must not be null.
explicit ReadingListDistillerPage(
+ const GURL& url,
web::BrowserState* browser_state,
FaviconWebStateDispatcher* web_state_dispatcher,
ReadingListDistillerPageDelegate* delegate);
@@ -97,6 +98,7 @@ class ReadingListDistillerPage : public dom_distiller::DistillerPageIOS {
// Continues distillation by calling superclass |OnLoadURLDone|.
void DelayedOnLoadURLDone(int delayed_task_id);
GURL original_url_;
+ bool distilling_main_page_;
FaviconWebStateDispatcher* web_state_dispatcher_;
ReadingListDistillerPageDelegate* delegate_;
« no previous file with comments | « ios/chrome/browser/dom_distiller/distiller_viewer.cc ('k') | ios/chrome/browser/reading_list/reading_list_distiller_page.mm » ('j') | no next file with comments »
@@ -45,10 +45,11 @@ class ReadingListDistillerPage : public dom_distiller::DistillerPageIOS {
public:
typedef base::Callback<void(const GURL&, const GURL&)> RedirectionCallback;
- // Creates a ReadingListDistillerPage. WebStates to download the pages will
- // be provided by web_state_dispatcher.
+ // Creates a ReadingListDistillerPage to distill |url|. WebStates to download
+ // the pages will be provided by web_state_dispatcher.
// |browser_state|, |web_state_dispatcher| and |delegate| must not be null.
explicit ReadingListDistillerPage(

Powered by Google App Engine
This is Rietveld 408576698